@@ -19,27 +19,21 @@ use Badger::Factory::Class
     debug     => 0,
     item      => 'codec',
     path      => 'Badger::Codec BadgerX::Codec',
-    import    => 'class CLASS',
+    import    => 'class',
     constants => 'HASH ARRAY DELIMITER PKG',
     constant  => {
         CODEC_METHOD  => 'codec',
         ENCODE_METHOD => 'encode',
         DECODE_METHOD => 'decode',
         ENCODING      => 'Badger::Codec::Encoding',
-    },
-    exports   => {
-        any   => 'Codec',
     };
 
 our $CODECS     = {
     # any codecs with non-standard capitalisation can go here, but 
     # generally we grok the module name from the $CODEC_PATH, e.g.
-    uri      => 'Badger::Codec::URI',
     url      => 'Badger::Codec::URL',
     yaml     => 'Badger::Codec::YAML',
     json     => 'Badger::Codec::JSON',
-    html     => 'Badger::Codec::HTML',
-    tt       => 'Badger::Codec::TT',
     map {
         my $name = $_; $name =~ s/\W//g;
         $_ => [ENCODING, ENCODING.PKG.$name],
@@ -47,11 +41,6 @@ our $CODECS     = {
 };
 
 
-sub Codec { 
-    CLASS->codec(@_);
-}
-
-
 sub codec {
     my $self = shift->prototype;
 
@@ -61,49 +50,36 @@ sub codec {
         : $self->item(@_);
 }
 
-
 sub chain {
     my $self = shift;
     $self->debug("creating chain for $_[0]\n") if $DEBUG;
     return CHAIN->new(@_);
 }
-
-
-sub found_object {
-    my ($self, $name, $item, $args) = @_;
-
-    # TODO: assert $item is a codec object?
-
-    # We cache any codecs that are created without configuration items
-    # but we can only use those "bare" codecs if $args is empty.  Otherwise
-    # we must create a new object
-    if (@$args) {
-        $self->debug("creating new ", ref $item, " codec for $name\n") if DEBUG;
-        return $self->construct($name, ref $item, $args);
-    }
-    else {
-        $self->debug("re-using cached codec for $name: $item\n") if $DEBUG;
-        return $item;
-    }
-}
-
-
-sub result {
-    my ($self, $name, $codec, $args) = @_;
-    # only cache codec objects created with no arguments
-    unless (@$args) {
-        $self->debug("Caching $name codec for subsequent re-used: $codec") if DEBUG;
-        $self->{ codecs }->{ $name } = $codec;
-    }
+ 
+sub found {
+    my ($self, $name, $codec) = @_;
+    # cache codec object and return
+    $self->{ codecs }->{ $name } = $codec;
     return $codec;
 }
 
+sub found_ref {
+    my ($self, $item, $config) = @_;
+    if (blessed $item) {
+        # codecs are cached for reuse, but we always create a new one if
+        # configuation parameters are provided.
+        $item = $item->new($config) if %$config;
+        return $item;
+    }
+    else {
+        $self->error_msg( bad_ref => codec => $item, ref $item );
+    }
+}
 
 sub encode {
     shift->codec(shift)->encode(@_);
 }
 
-
 sub decode {
     shift->codec(shift)->decode(@_);
 }
@@ -120,7 +96,6 @@ class->exports(
     }
 );
 
-
 sub _export_hook {
     my ($class, $target, $key, $symbols) = @_;
     croak "You didn't specify a value for the '$key' load option."
@@ -129,7 +104,6 @@ sub _export_hook {
     $class->$method($target, shift @$symbols);
 }
 
-
 sub export_codec {
     my ($class, $target, $name, $alias) = @_;
     my $codec   = $class->codec($name);
@@ -151,7 +125,6 @@ sub export_codec {
     *{$dmethod} = $codec->decoder;  # unless defined &{$dmethod};
 }
 
-
 sub export_codecs {
     my ($class, $target, $names) = @_;
     if (ref $names eq HASH) {
@@ -404,17 +377,6 @@ hash array.
     $encoded = encode_data($original);
     $decoded = decode_data($encoded);
 
-=head1 IMPORTABLE SUBROUTINES
-
-=head2 Codec()
-
-This subroutine can be used as a shortcut to the L<codec> method.
-
-    use Badger::Codecs 'Codec';
-    
-    my $yaml = Codec('YAML');
-    print $yaml->encode($some_data);
-
 =head1 METHODS
 
 =head2 new()
@@ -563,16 +525,10 @@ name of the module implementing the codec.
 This is an internal method called by the base class L<Badger::Factory>
 module when a codec is located and loaded.
 
-=head2 found_object($name,$codec)
+=head2 found_ref($name,$codec)
 
 This is an internal method called by the base class L<Badger::Factory>
-module when a cached codec object is found.
-
-=head2 result($name,$codec,\@args)
-
-This is an internal method called by the base class L<Badger::Factory>
-module to return a final result for the requested code.  This method
-caches the codec object if no configuration arguments were provided.
+module when a codec is located which is defined as a reference value.
 
 =head1 CONFIGURATION OPTIONS
 
@@ -610,14 +566,11 @@ mappings to bypass the automagical name grokking mechanism.
 
 =head1 AUTHOR
 
-Andy Wardley L<http://wardley.org/>
+Andy Wardley E<lt>abw@wardley.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2009 Andy Wardley. All rights reserved.
-
-This module is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+Copyright (C) 2005-2008 Andy Wardley. All rights reserved.
 
 =cut
 
