@@ -26,7 +26,6 @@ use constant {
     ARRAY           => 'ARRAY',
     HASH            => 'HASH',
     CODE            => 'CODE',
-    GLOB            => 'GLOB',
     REGEX           => 'Regexp',
     
     # constant values
@@ -60,7 +59,7 @@ CONSTANTS->export_any(qw(
 
 CONSTANTS->export_tags({
     types => [qw( 
-        SCALAR ARRAY HASH CODE GLOB REGEX
+        SCALAR ARRAY HASH CODE REGEX
     )],
     values => [qw(
         FALSE TRUE OFF ON ALL NONE DEFAULT
@@ -73,7 +72,7 @@ __END__
 
 =head1 NAME
 
-Badger::Constants - defines constants for other Badger modules
+Badger::Constants - defines constants for other TT modules
 
 =head1 SYNOPSIS
 
@@ -136,14 +135,6 @@ The literal word C<CODE>, typically used for testing references.
         ...
     }
 
-=head2 GLOB
-
-The literal word C<GLOB>, typically used for testing references.
-
-    if (ref $data eq GLOB) {
-        ...
-    }
-
 =head2 REGEX
 
 The literal word C<Regexp>, typically used for testing references.
@@ -265,7 +256,7 @@ Andy Wardley L<http://wardley.org/>
 
 =head1 COPYRIGHT
 
-Copyright (C) 1996-2009 Andy Wardley.  All Rights Reserved.
+Copyright (C) 1996-2008 Andy Wardley.  All Rights Reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
