@@ -19,7 +19,7 @@ package Badger::Exporter;
 use strict;
 use warnings;
 use Carp;
-use constant {
+use constant {              
     ALL          => 'all',             # Alas, we can't pull these in from 
     NONE         => 'none',            # Badger::Constants because it's a 
     DEFAULT      => 'default',         # subclass of Badger::Exporter which
@@ -40,10 +40,6 @@ use constant {
     ONCE         => 'once',
     PKG          => '::',
     DELIMITER    => qr/(?:,\s*)|\s+/,  # match a comma or whitespace
-    MISSING      => "Missing value for the '%s' option%s",
-    BAD_HOOK     => "Invalid export hook handler specified for the '%s' option: %s",
-    WANTED       => " (%s wanted, %s specified)",
-    UNDEFINED    => " (argument %s of %s is undefined)",
 };
 
 our $VERSION   = 0.01;
@@ -107,7 +103,7 @@ sub export_tags {
     $self->export_any(
         grep {
             # ignore references to code or other tag sets
-            not (ref || /^(:|=)/);
+            not (ref || /^:/);
         }
         map {
             # symbols in tagset can be a list ref, hash ref or string
@@ -171,8 +167,7 @@ sub export {
     my $can_hook  = (%$hooks ? 1 : 0);
     my $added_all = 0;
     my $count     = 0;
-    my ($symbol, $symbols, $source, $hook, $pkg, $nargs, 
-        %done, @args, @errors);
+    my ($symbol, $symbols, $source, $hook, $pkg, %done, @errors);
 
     no strict   REFS;
     no warnings ONCE;
@@ -225,15 +220,8 @@ sub export {
 #           _debug("expanded export pair: $symbol => $source\n") if $DEBUG;
         }
         elsif ($can_hook && ($hook = $hooks->{ $symbol })) {
-            # a hook can be specified as [$code,$nargs] in which case we 
-            # generate a closure around the $code which shifts $nargs off
-            # the symbols list and passes them as arguments to $code
-            $hook = $hooks->{ $symbol } = $class->export_hook_generator($symbol, $hook)
-                unless ref $hook eq CODE;
-
             # fire off handler hooked to this import item
             &$hook($class, $target, $symbol, $imports);
-
             # hooks can be repeated so pretend we haven't done it
             $done{ $symbol }--;     
             next SYMBOL;
@@ -295,15 +283,14 @@ sub export {
             my $type = "&";
             $symbol =~ s/^(\W)//;
             $source =~ s/^(\W)// and $type = $1;
-            $source = $pkg.PKG.$source unless $source =~ /::/ or $type eq '=';
+            $source = $pkg.PKG.$source unless $source =~ /::/;
            _debug("exporting $type$symbol from $source into $target\n") if $DEBUG;
             *{ $target.PKG.$symbol } =
-                $type eq '&' ?    \&{$source} :
-                $type eq '$' ?    \${$source} :
-                $type eq '@' ?    \@{$source} :
-                $type eq '%' ?    \%{$source} :
-                $type eq '*' ?     *{$source} :
-                $type eq '=' ? sub(){$source} :
+                $type eq '&' ? \&{$source} :
+                $type eq '$' ? \${$source} :
+                $type eq '@' ? \@{$source} :
+                $type eq '%' ? \%{$source} :
+                $type eq '*' ?  *{$source} :
                 do { push(@errors, "Can't export symbol: $type$symbol\n"); next; };
         }
         $count++;
@@ -352,8 +339,6 @@ sub exportables {
             # entries put in first by more specialised sub-classes are used 
             # in preference to those defined by more general super-classes.
             if ($symbols = ${ $pkg.PKG.EXPORT_ANY }) {
-                $symbols = [ split(DELIMITER, $symbols) ]
-                    unless ref $symbols eq ARRAY;
                 $any{ $_ } ||= $pkg
                     for @$symbols;
             }
@@ -361,8 +346,6 @@ sub exportables {
             # $EXPORT_ALL is merged into @all and all symbols are mapped 
             # to their packages in %any
             if ($symbols = ${ $pkg.PKG.EXPORT_ALL }) {
-                $symbols = [ split(DELIMITER, $symbols) ]
-                    unless ref $symbols eq ARRAY;
                 push(
                     @all,
                     map { $any{ $_ } ||= $pkg; $_ }
@@ -408,12 +391,13 @@ sub exportables {
 }
 
 sub export_symbol {
-    my ($self, $target, $symbol, $ref) = @_;
+    my ($self, $target, $symbol, $coderef) = @_;
     no strict   REFS;
     no warnings ONCE;
-    *{ $target.PKG.$symbol } = $ref;
+    *{ $target.PKG.$symbol } = $coderef;
 }
 
+
 sub export_variable {
     my ($self, $name, $default) = @_;
     my $class = ref $self || $self;
@@ -431,54 +415,6 @@ sub export_variable {
     return $item;
 }
 
-sub export_hook_generator {
-    my $self = shift;
-    my $name = shift;
-    my $hook = @_ == 1 ? shift : [ @_ ];
-    
-    # do nothing if we've already got a code ref that doesn't require args
-    return $hook 
-        if ref $hook eq CODE;
-    
-    # anything else must be a list ref containing [$code_ref, $n_args]
-    croak sprintf(BAD_HOOK, $name, $hook) 
-        unless ref $hook eq ARRAY;
-
-    my ($code, $nargs) = @$hook;
-
-    # user is trying to confuse us with [$non_code_ref, ...]
-    croak sprintf(BAD_HOOK, $name, $code) 
-        unless ref $code eq CODE;
-
-    # [$code, 0] or [$code] is fine as just $code, also reject $nargs < 0
-    return $code
-        unless $nargs && $nargs > 0;
-
-    # OK it's safe to proceed
-    return sub {
-        my ($this, $target, $symbol, $symbols) = @_;
-        my $n = 1;
-        # check we've got enough arguments
-        croak sprintf(MISSING, $symbol, sprintf(WANTED, $nargs, scalar @$symbols)) 
-            if @$symbols < $nargs;
-        
-        # call the code ref with the first $nargs arguments, making sure
-        # they all have defined values
-        $code->(
-            $this, $target, $symbol,
-            ( map {
-                croak sprintf(MISSING, $symbol, sprintf(UNDEFINED, $n, $nargs)) 
-                    unless defined $_;
-                $n++; 
-                $_
-              } 
-              splice(@$symbols, 0, $nargs)
-            ),
-            $symbols,
-        );
-    }
-}
-
 sub _debug {
     print STDERR @_;
 }
@@ -742,11 +678,11 @@ To load a set of symbols, specify the tag name with a 'C<:>' prefix.
 
 The special 'C<:all>' set imports all symbols.
 
-    use Badger::AnyModule ':all';
+    use Badger::AnyModule qw(:all);
 
 The special 'C<:default>' set imports the default set of symbols.
 
-    use Badger::AnyModule ':default @BONG';
+    use Badger::AnyModule qw(:default @BONG);
 
 You can also use the C<export_tags()> method to define a hash array
 mapping aliases to symbols.
@@ -763,7 +699,7 @@ When this tagset is imported, the symbols identified by the values
 in the hash reference (C<&the_foo_sub> and C<&the_bar_sub>) are exported 
 into the caller's package as the symbols named in the corresponding keys.
 
-    use Badger::AnyModule ':set4';
+    use Badger::AnyModule qw(:set4);
     
     foo();    # Badger::AnyModule::the_foo_sub()
     bar();    # Badger::AnyModule::the_bar_sub()
@@ -790,26 +726,6 @@ You can also explicitly specify the package name for a symbol:
         }
     );
 
-The C<Badger::Exporter> module also recognises the C<=> pseudo-sigil
-which can be used to define constant values.
-
-    __PACKAGE__->export_tags(
-        set7 => {   
-            e   => '=2.718',
-            pi  => '=3.142',
-            phi => '=1.618',
-        }
-    );
-
-When this tag set is imported, C<Badger::Exporter> will define constant
-subroutines to represent the imported values.
-
-    use Badger::AnyModule ':set7';
-    
-    print e;            # 2.718
-    print pi;           # 3.142
-    print phi;          # 1.618
-
 =head2 export_hooks(%hooks)
 
 Defines one or more handlers that are invoked when particular import
@@ -840,27 +756,6 @@ C<$more_symbols> list to indicate that they have been successfully handled.
 Any symbols left in the C<$more_symbols> list will continue to be imported 
 as usual.
 
-You can also define export hooks as an array reference. The code reference
-should be the first item in the array. The second item is the number of
-arguments it expects. These will be shifted off the C<$more_symbols> list
-(automatically raising an error if one or more values are missing or
-undefined) and passed as separate arguments to your handler. The
-C<$more_symbols> reference will be passed as the final argument.
-
-    __PACKAGE__->export_hooks(
-        example => [ \&my_export_hook, 2 ],
-    );
-    
-    sub my_export_hook {
-        my ($self, $target, $symbol, $arg1, $arg2, $more_symbols) = @_;
-        # your code...
-    }
-
-Hooks expressed this way will have closures created around them on demand
-by the L<export_hook_generator()> method.  Don't worry if that doesn't
-mean anything much to you.  It simply means that we can delay doing any
-extra preparation work until we're sure that it's going to be used.
-
 =head2 export_fail(\&handler)
 
 This method can be used to register a subroutine to handle any export
@@ -881,7 +776,7 @@ indicate failure which is then reported in the usual way.
             }
         }
     );
-
+    
 An C<export_fail> handler may also remove symbols from the C<$more_symbols>
 list to indicate that they have been handled, as per C<export_hooks()>.
 
@@ -916,63 +811,13 @@ package.
 
     Badger::Exporter->export_symbol('My::Package', 'Foo', \&foosub);
 
-=head2 export_hook_generator($name,\&code,$nargs)
-
-This method is used to generate a closure (a fancy way of saying "wrapper
-subroutine") around an existing export hook subroutine.  Bare naked export
-hooks are typically written like this:
-
-    sub code {
-        my ($self, $target, $symbol, $more_symbols) = @_
-        # your code...
-    }
-
-Your code is responsible for shifting any arguments it expects off the front
-of the C<$more_symbols> list. It I<should> also being doing all the messy
-stuff like making sure the C<$more_symbols> list contains enough arguments and
-that they're all set to defined values.  But I bet you forget sometimes, 
-don't you?  That's OK, it's easily done.
-
-The purpose of the C<export_hook_generator()> method is to simplify argument 
-processing so that hooks can be specified as:
-
-    [\&my_code, $nargs]
-
-and written as:
-
-    sub code {
-        my (
-            $self, $target, $symbol,    # the usual first three items
-            $arg1, $arg2, ..., $argn,   # your $nargs items
-            $more_symbols               # the remaining items
-        ) = @_
-    }
-
-The method should be called like something like this:
-
-    my $hook = Badger::Exporter->export_hook_generator(
-        'wibble', \&code, 2
-    );
-
-The first argument should be the name of the option that the hook is being
-generated for.  This is used to report any argument errors, e.g.
-
-    Missing value for the 'wibble' option (2 wanted, 1 available)
-
-Or:
-
-    Missing value for the 'wibble' option (argument 2 of 2 is undefined)
-
-The second argument is a reference to your handler subroutine.  The third
-argument is the number of additional arguments your subroutine expects.
-
 =head1 AUTHOR
 
 Andy Wardley L<http://wardley.org/>
 
 =head1 COPYRIGHT
 
-Copyright (C) 1996-2009 Andy Wardley.  All Rights Reserved.
+Copyright (C) 1996-2008 Andy Wardley.  All Rights Reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
