@@ -15,7 +15,6 @@ package Badger::Factory::Class;
 use Carp;
 use Badger::Class
     version   => 0.01,
-    debug     => 0,
     uber      => 'Badger::Class',
     hooks     => 'item path',
     words     => 'ITEM ITEMS',
@@ -45,8 +44,6 @@ sub _export_fail_hook {
         $items = plural($item) if $item;
     }
 
-#    $target->debug("looking for $items to match $symbol\n");
-
     # if the import symbols matches $items (e.g. widgets) then push the 
     # next argument into the relevant package var (e.g. $WIDGETS)
     if ($items && $items eq $symbol) {
@@ -82,13 +79,8 @@ sub path {
     $path = [ split(DELIMITER, $path) ]
         unless ref $path eq ARRAY;
 
-    $self->debug("adding $var => [", join(', ', @$path), "]") if DEBUG;
     $self->base(FACTORY);
-
-    # we use import_symbol() rather than var() so that it gets declared 
-    # properly, thus avoiding undefined symbol warnings
-    $self->import_symbol( $var => \$path );
-    
+    $self->var( $var => $path );
     return $self;
 }
 
@@ -155,7 +147,7 @@ Andy Wardley L<http://wardley.org/>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2006-2009 Andy Wardley.  All Rights Reserved.
+Copyright (C) 2006-2008 Andy Wardley.  All Rights Reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
