@@ -17,9 +17,9 @@ use Cwd 'getcwd';
 use Badger::Class
     version   => 0.01,
     debug     => 0,
-    base      => 'Badger::Prototype Badger::Filesystem::Base',
+    base      => 'Badger::Prototype',
     import    => 'class',
-    utils     => 'params is_object random_name',
+    utils     => 'params is_object',
     constants => 'HASH ARRAY TRUE REFS PKG',
     constant  => {
         virtual     => 0,
@@ -39,7 +39,7 @@ use Badger::Class
     exports   => {
         any         => 'FS PATH FILE DIR DIRECTORY cwd getcwd rel2abs abs2rel',
         tags        => { 
-            types   => 'Path File Dir Directory Cwd Bin',
+            types   => 'Path File Dir Directory Cwd',
             dirs    => 'ROOTDIR UPDIR CURDIR',
         },
         hooks       => {
@@ -54,15 +54,13 @@ use Badger::Class
         open_failed   => 'Failed to open %s %s: %s',
         delete_failed => 'Failed to delete %s %s: %s',
         bad_volume    => 'Volume mismatch: %s vs %s',
-        bad_stat      => 'Nothing known about %s',
-        copy_failed   => 'Failed to %s file from %s to %s: %s',
     };
 
 use Badger::Filesystem::File;
 use Badger::Filesystem::Directory;
 
 #-----------------------------------------------------------------------
-# special export hooks to make $Bin available from FindBin 
+# special export hook to make $Bin available from FindBin
 #-----------------------------------------------------------------------
 
 sub _export_findbin_hook {
@@ -87,7 +85,6 @@ sub _export_findbin_hook {
 *delete_dir   = \&delete_directory;
 *open_dir     = \&open_directory;
 *read_dir     = \&read_directory;
-*temp_dir     = \&temp_directory;
 *dir_child    = \&directory_child;
 *dir_children = \&directory_children;
 *mkdir        = \&create_directory;
@@ -122,8 +119,6 @@ sub Path      { return @_ ? FS->path(@_)      : PATH      }
 sub File      { return @_ ? FS->file(@_)      : FILE      }
 sub Directory { return @_ ? FS->directory(@_) : DIRECTORY }
 sub Cwd       { FS->directory }
-sub Bin       { class(FINDBIN)->load; 
-                FS->directory($FindBin::Bin) }
 
 
 #-----------------------------------------------------------------------
@@ -175,9 +170,6 @@ sub init {
     # current working can be specified explicitly, otherwise we leave it
     # undefined and let cwd() call getcwd() determine it dynamically
     $self->{ cwd } = $config->{ cwd };
-
-    # additional options, e.g. codec, encoding
-    $self->init_options($config);
     
     return $self;
 }
@@ -341,38 +333,18 @@ sub relative {
 #-----------------------------------------------------------------------
 
 sub path_exists {
-    shift->stat_path(@_);
+    my $self = shift;
+    return -e $self->definitive_read(shift);
 }
 
 sub file_exists {
-    my $self  = shift;
-    my $stats = $self->stat_path(shift) || return; 
-    return -f _ ? $stats : 0;       # relies on cached stat
+    my $self = shift;
+    return -f $self->definitive_read(shift);
 }
 
 sub directory_exists {
     my $self = shift;
-    my $stats = $self->stat_path(shift) || return; 
-    return -d _ ? $stats : 0;       # relies on cached stat
-}
-
-sub stat_path {
-    my $self  = shift;
-    my $path  = $self->definitive_read(shift) || return; 
-    my @stats = (stat($path), -r _, -w _, -x _, -o _, $path);
-
-    return $self->error_msg( bad_stat => $self->{ path } )
-        unless @stats;
-
-    return wantarray
-        ?  @stats
-        : \@stats;
-}
-
-sub chmod_path {
-    my $self = shift;
-    my $path = $self->definitive_write(shift);
-    chmod(shift, $path);
+    return -d $self->definitive_read(shift);
 }
     
 
@@ -412,7 +384,6 @@ sub open_file {
     my $self = shift;
     my $name = shift;
     my $mode = $_[0] || 'r';            # leave it in @_ for IO::File
-    my $opts = @_ && ref $_[-1] eq HASH ? pop(@_) : { };
     my $path = $mode eq 'r' 
         ? $self->definitive_read($name)
         : $self->definitive_write($name);
@@ -420,19 +391,13 @@ sub open_file {
     require IO::File;
     $self->debug("about to open file $path (", join(', ', @_), ")\n") if $DEBUG;
 
-    my $fh = IO::File->new($path, @_)
+    return IO::File->new($path, @_)
         || $self->error_msg( open_failed => file => $path => $! );
-
-    $fh->binmode( $opts->{ encoding } ) 
-        if $opts->{ encoding };
-
-    return $fh;
 }
 
 sub read_file {
     my $self = shift;
-    my $opts = @_ && ref $_[-1] eq HASH ? pop(@_) : { };
-    my $fh   = $self->open_file(shift, 'r', $opts);
+    my $fh   = $self->open_file(shift, 'r');
     return wantarray
         ? <$fh>
         : do { local $/ = undef; <$fh> };
@@ -440,8 +405,7 @@ sub read_file {
 
 sub write_file {
     my $self = shift;
-    my $opts = @_ && ref $_[-1] eq HASH ? pop(@_) : { };
-    my $fh   = $self->open_file(shift, 'w', $opts);
+    my $fh   = $self->open_file(shift, 'w');
     return $fh unless @_;           # return handle if no args
     print $fh @_;                   # or print args and close
     $fh->close;
@@ -450,8 +414,7 @@ sub write_file {
 
 sub append_file {
     my $self = shift;
-    my $opts = @_ && ref $_[-1] eq HASH ? pop(@_) : { };
-    my $fh   = $self->open_file(shift, 'a', $opts);
+    my $fh   = $self->open_file(shift, 'a');
     return $fh unless @_;           # return handle if no args
     print $fh @_;                   # or print args and close
     $fh->close;
@@ -459,73 +422,19 @@ sub append_file {
 }
 
 
-sub copy_file {
-    shift->_file_copy( copy => @_ );
-}
-
-sub move_file {
-    shift->_file_copy( move => @_ );
-}
-
-sub _file_copy {
-    require File::Copy;
-
-    my ($self, $action, $from, $to, $params) 
-     = (shift, shift, shift, shift, params(@_));
-     
-    my $src    
-        = is_object(PATH, $from)    ? $from->definitive     # path object
-        : ref($from)                ? $from                 # file handle
-        : $self->definitive_read($from);                    # file path
-
-    my $dest
-        = is_object(PATH, $to)      ? $to->definitive       # as above
-        : ref($to)                  ? $to            
-        : $self->definitive_write($to);
-    
-    my $code 
-        = $action eq 'copy' ? \&File::Copy::copy
-        : $action eq 'move' ? \&File::Copy::move
-        : return $self->error( invalid => action => $action );
-
-    my $file;
-
-    unless (ref $dest) {
-        # NOTE: don't use $self->file($dest) because $self could be a 
-        # VFS and $dest is already a definitive path
-        $file = File($dest);
-        $file->directory->must_exist(
-            $params->{ mkdir    },
-            $params->{ dir_mode },
-        );
-    }
-
-    $code->($src, $dest)
-        || return $self->error_msg( copy_failed => $action, $from, $to, $! );
-
-    my $mode = $params->{ file_mode };
-       $mode = $params->{ mode } unless defined $mode;
-
-    $file->chmod($mode) 
-        if $file && defined $mode;
-
-    return $file || $dest;
-}
-
-
 #-----------------------------------------------------------------------
 # directory manipulation methods
 #-----------------------------------------------------------------------
 
 sub create_directory { 
-    my $self   = shift;
-    my $path   = $self->definitive_write(shift);
+    my $self = shift;
+    my $path = $self->definitive_write(shift);
 
     require File::Path;
 
     eval { 
         local $Carp::CarpLevel = 1;
-        File::Path::mkpath($path, 0, @_) 
+        File::Path::mkpath($path, @_) 
     } || return $self->error($@);
 } 
     
@@ -581,26 +490,6 @@ sub directory_children {
     return wantarray ? @paths : \@paths;
 }
 
-
-#-----------------------------------------------------------------------
-# temporary directory/file methods
-#-----------------------------------------------------------------------
-
-sub temp_directory {
-    my $self = shift;
-    return $self->directory( FILESPEC->tmpdir, @_ )->must_exist(1);
-}
-
-sub temp_file {
-    my $self = shift;
-    return $self->temp_directory->file( @_ ? @_ : random_name() )
-}
-
-
-#-----------------------------------------------------------------------
-# visitor methods
-#-----------------------------------------------------------------------
-
 sub visitor {
     my $self  = shift;
     my $vtype = $self->VISITOR;
@@ -630,28 +519,26 @@ sub accept {
 sub _child_args {
     my $self = shift->prototype;
     my $type = shift;
-    my $args = { %{ $self->{ options } } };
-
-    if (@_ && ref $_[-1] eq HASH) {
-        my $more = pop @_;
-        @$args{ keys %$more } = values %$more;
-    }
-
-    if (@_ > 1) {
-        $args->{ path } = [@_];
+    my $args;
+    
+    if (! @_) {
+        $args = { path => undef };
     }
     elsif (@_ == 1) {
-        $args->{ path } = shift;
+        $args = ref $_[0] eq HASH ? shift : { path => shift };
+#            : ! ref $_[0] ? { path => shift }
+#            : return $self->error_msg( unexpected => "$type arguments" => $_[0], 'hash ref' )
     }
     else {
-        $args->{ path } = undef;
+        $args = { path => [@_] };
     }
-
     $args->{ filesystem } = $self;
     return $args;
 }
 
 
+# TODO: move file?
+
 
 1;
 
@@ -941,23 +828,12 @@ path as a single string or list of path components.
 This returns a L<Badger::Filesystem::Directory> object for the current
 working directory.
 
-    use Badger::Filesystem 'Cwd';
+    use Badger::Filesystem Cwd;
     
     print Cwd;              # /foraging/for/nuts/and/berries
     print Cwd->parent;      # /foraging/for/nuts/and
 
-=head2 Bin()
-
-This returns a L<Badger::Filesystem::Directory> object for the directory
-in which the currently executing script is located.  It is a simple 
-wrapper around the value defined in L<$Bin>.
-
-    use Badger::Filesystem 'Bin';
-    
-    print Bin;              # /path/to/current/script
-    print Bin->parent;      # /path/to/current
-
-=head2 cwd()
+=head2 cwd
 
 This returns a simple text string representing the current working directory.
 It is a a wrapper around the C<getcwd> function in L<Cwd>.  It also 
@@ -978,19 +854,17 @@ This is exactly the same as:
     use FindBin '$Bin';
     use lib "$Bin/../lib";
 
-One benefit is that you can use it in conjunction with other import options
-to save on a little typing.  For example:
+The benefit is that you can use it in conjunction with other import options.
 
-    use Badger::Filesystem 'Cwd File $Bin';
+    use Badger::Filesystem '$Bin Cwd File';
 
 Compared to something like:
 
+    use FindBin '$Bin';
     use Cwd;
     use Path::Class;
-    use FindBin '$Bin';
-    use lib "$Bin/../lib";
 
-=head2 getcwd()
+=head2 getcwd
 
 This is a direct alias to the C<getcwd> function in L<Cwd>.
 
@@ -1113,7 +987,7 @@ name into a single path.  This is a wrapper around the
 L<catpath()|File::Spec/catpath()> and L<canonpath()|File::Spec/canonpath()> 
 functions in L<File::Spec>.
 
-    my $path = $fs->join_path($volume, $directory, $file);
+    my $path = $fs−>join_path($volume, $directory, $file);
 
 =head2 split_dir($dir) / split_directory($dir)
 
@@ -1127,11 +1001,11 @@ around the L<splitdir()|File::Spec/splitdir()> function in L<File::Spec>.
 Combines multiple directory names into a single path.  This is a wrapper
 around the L<catdir()|File::Spec/catdir()> function in L<File::Spec>.
 
-    my $dir = $fs->join_dir('path', 'to', 'my', 'dir');
+    my $dir = $fs−>join_dir('path', 'to', 'my', 'dir');
 
 The final element can also be a file name.   TODO: is that portable?
 
-    my $dir = $fs->join_dir('path', 'to', 'my', 'file');
+    my $dir = $fs−>join_dir('path', 'to', 'my', 'file');
 
 =head2 collapse_dir($dir) / collapse_directory($dir)
 
@@ -1263,45 +1137,6 @@ Returns true if the path exists and is a file, false if not.
 
 Returns true if the path exists and is a directory, false if not.
 
-=head2 stat_path($path)
-
-Performs a C<stat()> on the filesystem path.  It returns a list (in list 
-context) or a reference to a list (in scalar context) containing 17 items.
-The first 13 are those returned by Perl's inbuilt C<stat()> function.  The
-next 3 items are flags indicating if the file is readable, writeable and/or
-executable.  The final item is a flag indicating if the file is owned by the
-current user (i.e. owner of the current process.
-
-A summary of the fields is shown below. See C<perldoc -f stat> and the
-L<stat()|Badger::Filesystem::Path/stat()> method in
-L<Badger::Filesystem::Path> for further details.
-
-    Field   Description
-    --------------------------------------------------------
-      0     device number of filesystem
-      1     inode number
-      2     file mode  (type and permissions)
-      3     number of (hard) links to the file
-      4     numeric user ID of file’s owner
-      5     numeric group ID of file’s owner
-      6     the device identifier (special files only)
-      7     total size of file, in bytes
-      8     last access time in seconds since the epoch
-      9     last modify time in seconds since the epoch
-     10     inode change time in seconds since the epoch (*)
-     11     preferred block size for file system I/O
-     12     actual number of blocks allocated
-     13     file is readable by current process
-     14     file is writeable by current process
-     15     file is executable by current process
-     16     file is owned by current process
-
-=head2 chmod_path($path)
-
-Changes the file permissions on a path.
-
-    $fs->chmod_path('/path/to/file', 0755);
-
 =head1 FILE MANIPULATION METHODS
 
 =head2 create_file($path)
@@ -1373,37 +1208,6 @@ to indicate success.  Errors are thrown as exceptions.
 
     $fs->append_file('/path/to/file', "Hello World\n", "Regards, Badger\n");
 
-=head2 copy_file($from, $to, %params)
-
-Copies a file from the C<$from> path to the C<$to> path, using L<File::Copy>
-
-    $fs->copy_file($from, $to);
-
-The C<$from> and C<$to> arguments can be file names, file objects, or file
-handles.
-
-An optional list or reference to a hash array of named parameters can follow
-the file names.  The C<mkdir> option can be set to indicate that 
-the destination direction should be created if it doesn't already exist,
-along with any intermediate directories.  
-
-    $fs->copy_file($from, $to, mkdir => 1);
-
-The C<dir_mode> parameter can be used to specify the octal file 
-permissions for any directories created.
-
-    $fs->copy_file($from, $to, 1, mkdir => 1, dir_mode => 0770);
-
-The C<file_mode> parameter (or C<mode> for short) can be used to specify the
-octal file permissions for the created file.
-
-    $fs->copy_file($from, $to, file_mode => 0644);
-
-=head2 move_file($from, $to, %params)
-
-Moves a file from the C<$from> path to the C<$to> path, using L<File::Copy>.
-The arguments are as per L<copy_file()>.
-
 =head1 DIRECTORY MANIPULATION METHODS
 
 =head2 create_dir($path) / create_directory($path) / mkdir($path)
@@ -1463,28 +1267,6 @@ returned as L<Badger::Filesystem::File> objects, directories as
 L<Badger::Filesystem::File> objects. Anything else is returned as a generic
 L<Badger::Filesystem::Path> object.
 
-=head1 TEMPORARY DIRECTORY AND FILE METHODS
-
-=head2 temp_dir($dir) / temp_directory($dir)
-
-This returns a reference to a L<Badger::Filesystem::Directory> object for the
-temporary directory on your system (as reported by C<tmpdir> in L<File::Spec>).
-
-    my $tmp = $fs->temp_dir;
-
-If any arguments are specified then they are appended as sub-directories to
-the temporary directory path.
-
-    my $tmp = $fs->temp_dir('foo', 'bar');  # e.g. /tmp/foo/bar 
-
-=head2 temp_file($name)
-
-This returns a reference to a L<Badger::Filesystem::File> object for a named
-file created in the temporary directory returned by the L<temp_directory()>
-method.
-
-    my $file = $fs->temp_file('foo.tmp');   # e.g. /tmp/foo.tmp
-
 =head1 VISITOR METHODS
 
 =head2 visitor(\%params)
@@ -1542,34 +1324,6 @@ if you want a L<Badger::Filesystem::Directory> object instead.
 Returns a L<Badger::Filesystem::Directory> object representing the root
 directory for the filesystem.
 
-=head2 rootdir
-
-Returns a text string containing the representation of the root directory
-for your filesystem.  
-
-    print $fs->rootdir;             # e.g. '/' on Unix-based file systems
-
-=head2 updir
-
-Returns a text string containing the representation of the parent directory
-for your filesystem.  
-
-    print $fs->updir;               # e.g. '..' on Unix-based file systems
-
-=head2 curdir
-
-Returns a text string containing the representation of the current directory
-for your filesystem.  
-
-    print $fs->curdir;              # e.g. '.' on Unix-based file systems
-
-=head2 separator
-
-Returns a text string containing the representation of the path separator
-for your filesystem.  
-
-    print $fs->separator;           # e.g. '/' on Unix-based file systems
-
 =head1 EXPORTABLE CONSTANTS
 
 =head2 FS
@@ -1595,14 +1349,11 @@ An alias for C<Badger::Filesystem::Directory>
 
 =head1 AUTHOR
 
-Andy Wardley L<http://wardley.org/>
+Andy Wardley E<lt>abw@wardley.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2009 Andy Wardley. All rights reserved.
-
-This module is free software; you can redistribute it and/or
-modify it under the same terms as Perl itself.
+Copyright (C) 2005-2008 Andy Wardley. All rights reserved.
 
 =head1 ACKNOWLEDGEMENTS
 
