@@ -14,11 +14,9 @@ package Badger::Filesystem::File;
 
 use Badger::Class
     version     => 0.01,
-    base        => 'Badger::Filesystem::Path',
     debug       => 0,
-    dumps       => 'path volume directory name stats',
-    import      => 'class',
-    constants   => 'ARRAY BLANK',
+    base        => 'Badger::Filesystem::Path',
+    constants   => 'ARRAY',
     constant    => {
         type    => 'File',
         is_file => 1,
@@ -27,8 +25,6 @@ use Badger::Class
 use Badger::Filesystem::Path ':fields';
 
 *base = \&directory;
-*copy = \&copy_to;
-*move = \&move_to;
 
 sub init {
     my ($self, $config) = @_;
@@ -46,11 +42,6 @@ sub init {
     else {
         $self->error_msg( missing => 'path or name' );
     }
-    
-    my $opts = $self->{ options } = { };
-    $self->encoding( $config->{ encoding } )
-        if $config->{ encoding };
-        
     return $self;
 }
 
@@ -70,8 +61,7 @@ sub file {
 
 sub exists {
     my $self = shift;
-    # cache the stats returned in case we want them later
-    return ($self->{ stats } = $self->filesystem->file_exists($self->{ path }));
+    $self->filesystem->file_exists($self->{ path });
 }
 
 sub create {
@@ -86,47 +76,22 @@ sub touch {
 
 sub open {
     my $self = shift;
-    $self->filesystem->open_file($self->{ path }, @_, $self->{ options });
+    $self->filesystem->open_file($self->{ path }, @_);
 }
 
 sub read {
     my $self = shift;
-    $self->filesystem->read_file($self->{ path }, @_, $self->{ options });
+    $self->filesystem->read_file($self->{ path }, @_);
 }
 
 sub write {
     my $self = shift;
-    $self->filesystem->write_file($self->{ path }, @_, $self->{ options });
-}
-
-sub copy_to {
-    my $self = shift;
-    $self->filesystem->copy_file($self->{ path }, @_);
-}
-
-sub copy_from {
-    my $self = shift;
-    $self->filesystem->copy_file(shift, $self->{ path }, @_);
-}
-
-sub move_to {
-    my $self = shift;
-    $self->filesystem->move_file($self->{ path }, @_);
-}
-
-sub move_from {
-    my $self = shift;
-    $self->filesystem->move_file(shift, $self->{ path }, @_);
-}
-
-sub print {
-    my $self = shift;
-    $self->write( join(BLANK, @_) );
+    $self->filesystem->write_file($self->{ path }, @_);
 }
 
 sub append {
     my $self = shift;
-    $self->filesystem->append_file($self->{ path }, @_, $self->{ options });
+    $self->filesystem->append_file($self->{ path }, @_);
 }
 
 sub delete {
@@ -135,8 +100,7 @@ sub delete {
 }
 
 sub text {
-    my $self = shift;
-    my $text = $self->read(@_, $self->{ options });
+    my $text = shift->read(@_);
     # TODO: bless?
     return $text;
 }
@@ -145,35 +109,8 @@ sub accept {
     $_[1]->visit_file($_[0]);
 }
 
-sub encoding {
-    my $self = shift;
-    if (@_) {
-        my $layer = shift;
-        # be generous in what you accept...
-        $layer = ":$layer" unless $layer =~ /^:/;
-        $self->{ options }->{ encoding } = $layer;
-    }
-    return $self->{ options }->{ encoding };
-}
-
-class->methods(
-    map {
-        my $item = $_;              # lexical copy for closure
-        $item => sub {
-            my $self = shift;
-            # ...and strict in what you provide
-            $self->encoding(':' . $item); 
-            return $self;
-        }
-    }
-    qw( raw utf8 crlf bytes )
-);
-
-
 1;
 
-__END__
-
 =head1 NAME
 
 Badger::Filesystem::File - file object
@@ -267,12 +204,6 @@ of component names.
     my $file = File('path', 'to', 'file');
     my $file = File(['path', 'to', 'file']);
 
-You can specify a reference to a hash array of additional configuration items
-as the final argument.  At present, there is only one configuration option,
-C<encoding>, which you can use to specify the encoding of the file.
-
-    my $file = File('path' , 'to', 'file', { encoding => 'utf8' });
-
 =head1 METHODS
 
 In addition to the methods inherited from L<Badger::Filesystem::Path>, the
@@ -280,7 +211,7 @@ following methods are defined or re-defined.
 
 =head2 init(\%config)
 
-Customised initialisation method specific to files.  
+Customised initialisation method specific to files.
 
 =head2 volume() / vol()
 
@@ -360,56 +291,6 @@ it, and then closes the file again.
 
     $file->write("Hello World!\n");
 
-=head2 copy($to, %params) / copy_to($to, %params)
-
-This method copies the file to the new location specified by the first
-argument. It delegates to the L<copy_file()|Badger::Filesystem/copy_file()>
-method in L<Badger::Filesystem>.
-
-    $file->copy('/some/where/else');
-
-The destination can be specified as a file name, file object or file handle.
-An optional list of reference to a hash array of named parameters can follow.
-
-    $file->copy(
-        '/some/where/else' => {
-            mkdir     => 1,         # create intermediate directories
-            dir_mode  => 0775,      # permissions for created directories
-            file_mode => 0664,      # permissions for created file
-        }
-    );
-
-=head2 copy_from($from, %params)
-
-Like L<copy_to()> but working in reverse. 
-
-    $target_file->copy_from( $source_file );
-
-=head2 move($to, %params) / move_to($to, %params)
-
-This method moves the file to the new location specified by the first
-argument.  It delegates to the L<copy_file()|Badger::Filesystem/move_file()>
-method in L<Badger::Filesystem>.
-
-    $file->move('/some/where/else');
-
-Arguments are as per L<copy()>.
-
-=head2 move_from($from, %params)
-
-Like L<move_to()> but working in reverse. 
-
-    $target_file->move_from( $source_file );
-
-=head2 print(@content)
-
-This method concatentates all arguments into a single string which it then
-forwards to the L<write()> method.  This effectively forces the L<write()>
-method to always write something to the file, even if it's an empty string.
-
-    $file->print("hello");      
-    $file->print(@stuff);       # works OK if @stuff is empty 
-
 =head2 append(@content)
 
 This method is similar to L<write()>, but opens the file for appending (when 
@@ -440,54 +321,13 @@ filesystem object.  In the L<Badger::Filesystem::File> class, it calls the
 visitor L<visit_file()|Badger::Filesystem::Visitor/visit_file()> method,
 passing the C<$self> object reference as an argument.
 
-=head2 encoding($enc)
-
-This method can be used to get or set the encoding for the file.
-
-    $file->encoding(':utf8');
-
-The encoding will affect all operations that read data from, or write data
-to the file.
-
-=head2 utf()
-
-A method of convenience to set the file's encoding to UTF-8.  
-
-    $file->utf8;
-
-It has the same affect as calling the L<encoding()> method with an argument
-of C<:utf8>.  See C<perldoc -f binmode> for further information.
-
-    # same
-    $file->encoding(':utf8');
-
-
-The method returns the file object itself, so can be used in a chain.
-
-    $file->utf8->must_exist.
-
-=head2 bytes()
-
-Like C<utf8()>, this is a method of convenience to set the file encoding 
-to C<:bytes>.
-
-=head2 crlf()
-
-Like C<utf8()>, this is a method of convenience to set the file encoding 
-to C<:crlf>.
-
-=head2 raw()
-
-Like C<utf8()>, this is a method of convenience to set the file encoding 
-to C<:raw>.
-
 =head1 AUTHOR
 
-Andy Wardley L<http://wardley.org/>
+Andy Wardley E<lt>abw@wardley.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2009 Andy Wardley. All rights reserved.
+Copyright (C) 2005-2008 Andy Wardley. All rights reserved.
 
 =head1 ACKNOWLEDGEMENTS
 
