@@ -17,21 +17,18 @@ use File::Spec;
 use Badger::Class
     version      => 0.01,
     debug        => 0,
-    base         => 'Badger::Filesystem::Base Badger::Exporter',
+    base         => 'Badger::Base Badger::Exporter',
     import       => 'class',
     constants    => 'HASH ARRAY TRUE',
     get_methods  => 'path name volume directory',
     utils        => 'blessed',
-    as_text      => 'path',
-    is_true      => 1,
     constant     => {
         is_file      => 0,
         is_directory => 0,
         type         => 'Path',
-        STAT_PATH    => 17,         # offset in extended stat fields
     },
     exports      => {
-        tags     => { fields => '@STAT_FIELDS' },
+        tags     => { fields => '@VDN_FIELDS @VD_FIELDS @STAT_FIELDS' },
     },
     messages     => {
         no_exist => '%s does not exist: %s',
@@ -40,68 +37,35 @@ use Badger::Class
         missing  => 'No %s specified',
     };
 
-use Badger::Timestamp;
+use overload
+    '""'     => \&path,
+    bool     => \&TRUE,
+    fallback => 1;
+
 use Badger::Filesystem;
 use Badger::Filesystem::Directory;
 
-
 our $FILESYSTEM  = 'Badger::Filesystem';
-our $TIMESTAMP   = 'Badger::Timestamp';
-our $MATCH_EXT   = qr/\.([^\.]+)$/;       # TODO: is this filesystem-specific?
-our @VDN_FIELDS  = @Badger::Filesystem::Base::VDN_FIELDS;
+our @VDN_FIELDS  = qw( volume directory name );
+our @VD_FIELDS   = qw( volume directory );
 our @STAT_FIELDS = qw( device inode mode links user group device_type 
-                       size atime mtime ctime block_size blocks
+                       size accessed modified created block_size blocks 
                        readable writeable executable owner );
-our $STAT_FIELD  = { 
-    # In here we'll store the map from stat field name to number
-    #   device => 0,
-    #   inode  => 1, 
-    #   ...etc...
-};
 
-our $TS_FIELD = {
-    # On the left we have the timestamp methods we want to generate as 
-    # wrappers around the stat fields listed on the right.
-    created  => 'ctime',
-    accessed => 'atime',
-    modified => 'mtime',
-};
-
-# generate methods to access stat fields: mode(), atime(), ctime(), etc.
+# generate methods to access stat fields
 my $n = 0;
-
 class->methods(
     map { 
-        my $m = $n++;                       # new lexical variable for closure
-        $STAT_FIELD->{ $_ } = $m;           # fill in $STAT_FIELD entry
-        $_ => sub { $_[0]->stats->[$m] }    # generate subroutine
-    } 
-    @STAT_FIELDS
+        my $m = $n++;       # new lexical variable to bind in closure
+        $_ => sub { $_[0]->stats->[$m] }
+    } @STAT_FIELDS
 );
 
-# generate accessed(), created() and modified() methods which return
-# Badger::Timestamp objects for the atime, ctime and mtime stat values
-
-class->methods(
-    map { 
-        my $method = $_;                    # new lexical variable for closure
-        my $stat   = $TS_FIELD->{ $_ };
-        my $statno = $STAT_FIELD->{ $stat };
-        $method => sub { 
-            return $_[0]->{ $method } 
-                ||= $TIMESTAMP->new( $_[0]->stats->[$statno] )
-        }
-    } 
-    keys %$TS_FIELD
-);
-
-
 # define some aliases
 *is_dir    = \&is_directory;
 *dir       = \&directory;
 *vol       = \&volume;     # goes up to 11
 *ext       = \&extension;  
-*base_name = \&basename;
 *up        = \&parent;
 *meta      = \&metadata;
 *canonical = \&absolute;
@@ -175,17 +139,14 @@ sub relative {
 
 sub definitive {
     my $self = shift;
-    # use the definitive path from the last stat or fetch anew
-    return 
-        ($self->{ stats } && $self->{ stats }->[STAT_PATH])
-      || $self->filesystem->definitive($self->{ path });
+    $self->filesystem->definitive($self->{ path });
 }
 
 sub collapse {
     my $self = shift->absolute;
     my $fs   = $self->filesystem;
-    $self->{ directory } = $fs->collapse_directory( $self->{ directory } );
-    $self->{ path      } = $fs->join_path( @$self{ @VDN_FIELDS } );
+    $self->{ directory } = $fs->collapse_directory($self->{ directory });
+    $self->{ path      } = $fs->join_path(@$self{@VDN_FIELDS});
     return $self;
 }
 
@@ -260,7 +221,8 @@ sub path_up {
 }
 
 sub exists {
-    shift->stat;
+    my $self = shift;
+    $self->filesystem->path_exists($self->{ path });
 }
 
 sub must_exist {
@@ -268,9 +230,8 @@ sub must_exist {
 
     unless ($self->exists) {
         if (@_ && $_[0]) {
-            my $flag = shift;
-            # true flag indicates we should attempt to create it
-            $self->create(@_);      # pass any other args, like dir file permission
+            # true flag to attempt
+            $self->create;
         }
         else {
             return $self->error_msg( no_exist => $self->type, $self->{ path } );
@@ -285,17 +246,13 @@ sub create {
 
 sub stat {
     my $self  = shift->must_exist;
-    my $stats = $self->{ stats } 
-              = $self->filesystem->stat_path($self->{ path })
-             || return $self->decline_msg( not_found => file => $self->{ path } );
-
-    # the definitive path can be tagged on the end
-#    $self->{ definitive } = $stats->[STAT_PATH]
-#        if defined $stats->[STAT_PATH];
-        
+    my @stats = (CORE::stat($self->{ path }), -r _, -w _, -x _, -o _);
+    return $self->error_msg( bad_stat => $self->type, $self->{ path } )
+        unless @stats;
+    $self->{ stats } = \@stats;
     return wantarray 
-        ? @$stats
-        :  $stats;
+        ?  @stats
+        : \@stats;
 }
 
 sub stats {
@@ -305,23 +262,10 @@ sub stats {
         :  $stats;
 }
 
-sub chmod {
-    my $self = shift;
-    $self->filesystem->chmod_path($self->{ path }, @_);
-    return $self;
-}
-
-sub basename {
-    my $self = shift;
-    my $name = $self->name;
-    $name = $self->{ path } unless defined $name;
-    $name =~ s/$MATCH_EXT//g;
-    return $name;
-}
-
 sub extension {
     my $self = shift;
-    return $self->{ path } =~ $MATCH_EXT
+    # TODO: is this filesystem specific?
+    return $self->{ path } =~ /\.([^\.]+)$/
         ? $1
         : '';
 }
@@ -405,8 +349,6 @@ Badger::Filesystem::Path - generic fileystem path object
     $path->path;                    # current path
     $path->base;                    # parent directory or path itself
     $path->parent;                  # directory object for base
-    $path->extension                # filename .XXX extension
-    $path->basename                 # filename without .XXX extension
     $path->is_absolute;             # path is absolute
     $path->is_relative;             # path is relative
     $path->exists;                  # returns true/false
@@ -605,7 +547,7 @@ filesystem).
     my $path = Path('/foo/bar/../baz')->collapse;
     print $path;   # /foo/baz
 
-See the L<collapse_dir()|Badger::Filesystem/collapse_dir()> method in 
+See the L<collapse_dir()|Badger::Filesystem/collapse()> method in 
 L<Badger::Filesystem> for further information.
 
 =head2 above($child)
@@ -678,6 +620,10 @@ root directory ('/') will be returned.  A relative path with only one item
 (e.g. 'foo') is assumed to be relative to the current working directory
 which will be returned (e.g. '/path/to/current/dir').
 
+=head2 extension() / ext()
+
+Returns any file extension portion following the final C<.> in the path.
+
 =head2 exists()
 
 Returns true if the path exists in the filesystem (e.g. as a file, directory,
@@ -716,50 +662,17 @@ L<Badger::Filesystem::Directory> subclasses.
     $dir->create;                           # OK
     $file->create;                          # OK
 
-=head2 chmod($perms)
-
-This method changes the file permissions on a file or directory.
-
-    $file->chmod(0775);
-
 =head2 stat()
 
 Performs a filesystem C<stat> on the path and returns a list (in list
 context), or a reference to a list (in scalar context) containing the 13 
-information elements.
+information elements.  See C<perldoc -f stat> for further details on what
+they are.
 
     @list = $path->stat;                    # list context
     $list = $path->stat;                    # scalar context
 
-A summary of the fields is shown below. See C<perldoc -f stat> for complete
-details. Each of the individual fields can also be accessed via their own
-methods, also listed in the table.
-
-    Field   Method          Description
-    ------------------------------------------------------------------------
-      0     device()        device number of filesystem
-      1     inoode()        inode number
-      2     mode()          file mode  (type and permissions)
-      3     links()         number of (hard) links to the file
-      4     user()          numeric user ID of file’s owner
-      5     group()         numeric group ID of file’s owner
-      6     device_type()   the device identifier (special files only)
-      7     size()          total size of file, in bytes
-      8     accessed()      last access time in seconds since the epoch
-      9     modified()      last modify time in seconds since the epoch
-     10     created()       inode change time in seconds since the epoch (*)
-     11     block_size()    preferred block size for file system I/O
-     12     blocks()        actual number of blocks allocated
-
-In addition to those that are returned by Perl's inbuilt C<stat> function,
-this method returns four additional flags.
-
-     13     readable()      file is readable by current process
-     14     writeable()     file is writeable by current process
-     15     executable()    file is executable by current process
-     16     owner()         file is owned by current process
-
-=head2 stats()
+=head2 stats
 
 A wrapper around the L<stat()> method which caches the results to avoid 
 making repeated filesystem calls.
@@ -767,108 +680,6 @@ making repeated filesystem calls.
     @list = $path->stats;                   # list context
     $list = $path->stats;                   # scalar context
 
-=head2 device
-
-Returns the device number for the file.  See L<stat()>.
-
-=head2 inode 
-
-Returns the inode number for the file.  See L<stat()>.
-
-=head2 mode
-
-Returns the file mode for the file.  See L<stat()>.
-
-=head2 links
-
-Returns the number of hard links to the file.  See L<stat()>.
-
-=head2 user
-
-Returns the numeric user ID of the file's owner.  See L<stat()>.
-
-=head2 group
-
-Returns the numeric group ID of the file's group.  See L<stat()>.
-
-=head2 device_type 
-
-Returns the device identifier (for special files only).  See L<stat()>.
-
-=head2 size
-
-Returns the total size of the file in bytes.  See L<stat()>.
-
-=head2 atime
-
-Returns the time (in seconds since the epoch) that the file was last accessed.
-See L<stat()>.
-
-=head2 accessed
-
-Returns a L<Badger::Timestamp> object for the L<atime()> value.  This object
-will auto-stringify to produce an ISO-8601 formatted date.  You can also 
-call various methods to access different parts of the time and/or date.
-
-    print $file->accessed;              # 2009/04/20 16:25:00
-    print $file->accessed->date;        # 2009/04/20
-    print $file->accessed->year;        # 2009
-
-=head2 mtime
-
-Returns the time (in seconds since the epoch) that the file was last modified.
-See L<stat()>.
-
-=head2 modified
-
-Returns a L<Badger::Timestamp> object for the L<mtime()> value.
-
-    print $file->modified;              # 2009/04/20 16:25:00
-    print $file->modified->time;        # 16:25:0
-    print $file->modified->hour;        # 16
-
-=head2 ctime
-
-Returns the time (in seconds since the epoch) that the file was created. See
-L<stat()>.
-
-=head2 created
-
-Returns a L<Badger::Timestamp> object for the L<ctime()> value.
-
-    print $file->created;               # 2009/04/20 16:25:00
-    print $file->created->date;         # 2009/04/20
-    print $file->created->time;         # 16:25:00
-
-=head2 block_size
-
-Returns the preferred block size for file system I/O on the file. See
-L<stat()>.
-
-=head2 blocks 
-
-Returns the actual number of blocks allocated to the file. See L<stat()>.
-
-=head2 readable
-
-Returns a true value if the file is readable by the current user (i.e. the
-owner of the current process), false if not.  See L<stat()>.
-
-=head2 writeable
-
-Returns a true value if the file is writeable by the current user (i.e. the
-owner of the current process), false if not.  See L<stat()>.
-
-=head2 executable
-
-Returns a true value if the file is executable by the current user (i.e. the
-owner of the current process), false if not.  See L<stat()>.
-
-=head2 owner                       
-
-Returns a true value if the file is owned by the current user (i.e. the
-owner of the current process), false if not.  See L<stat()>.
-
 =head2 filesystem
 
 Returns a reference to a L<Badger::Filesystem> object, or the name of the
@@ -997,38 +808,13 @@ C<Badger::Filesystem::Path> base class.
 Returns the file name portion of a path. This method does nothing in the
 C<Badger::Filesystem::Path> base class.
 
-=head2 extension() / ext()
-
-Returns any file extension portion following the final C<.> in the path.
-This works in the C<Badger::Filesystem::Path> base class by looking at the
-full path.
-
-    print Path('/foo/bar.txt')->extension;      # txt
-
-=head2 basename() / base_name()
-
-Returns the filename I<without> the file extension following the final 
-C<.> in the path.  This works (for some definition of "works") in the 
-C<Badger::Filesystem::Path> base class by looking at the path L<name()>,
-if defined, or the full C<path> if not.  Note that this will produce 
-unexpected results in some cases due to the fact that the base class 
-does not define a value for L<name()>.  e.g.
-
-    print Path('/foo/bar.txt')->basename;       # /foo/bar
-
-However, in most cases you would be using this through a
-L<Badger::Filesystem::File> subclass which will product the correct 
-results.
-
-    print File('/foo/bar.txt')->basename;       # bar
-
 =head1 AUTHOR
 
-Andy Wardley L<http://wardley.org/>
+Andy Wardley E<lt>abw@wardley.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2009 Andy Wardley. All rights reserved.
+Copyright (C) 2005-2008 Andy Wardley. All rights reserved.
 
 =head1 ACKNOWLEDGEMENTS
 
