@@ -1,44 +1,29 @@
 package Badger::Test;
 
 use Carp;
-use Badger;
 use Badger::Class
     version   => 0.01,
     base      => 'Badger::Base',
     import    => 'CLASS class',
     constants => 'ARRAY DELIMITER PKG',
-    words     => 'DEBUG DEBUG_MODULES',
+    words     => 'DEBUG',
     exports   => {
         all   => 'plan ok is isnt like unlike pass fail     
-                  skip_some skip_rest skip_all',
+                  skip_some skip_rest skip_all',        # NOTE: changed skip...
         hooks => {
-            lib      => [\&_lib_hook,  1],
-            skip     => [\&_skip_hook, 1],
+            skip     => \&_skip_hook,                   # ...to be a hook
             debug    => \&_debug_hook,
             map { $_ => \&_export_hook }
             qw( manager summary colour color args tests )
         },
     };
 
-use Badger::Debug;
-use Badger::Exception;
 use Badger::Test::Manager;
-our $MANAGER   = 'Badger::Test::Manager';
-our $DEBUGGER  = 'Badger::Debug';
-our $EXCEPTION = 'Badger::Exception';
-our ($DEBUG, $DEBUG_MODULES);
+our $MANAGER = 'Badger::Test::Manager';
+our ($DEBUG, $DEBUGGING);
 
 *color = \&colour;
 
-
-sub _lib_hook {
-    Badger->lib($_[3]);
-}
-
-sub _skip_hook {
-    $MANAGER->skip_all($_[3]);
-}
-
 sub _export_hook {
     my ($class, $target, $key, $symbols) = @_;
     croak "You didn't specify a value for the '$key' load option"
@@ -53,13 +38,18 @@ sub _debug_hook {
 
     # define $DEBUG in caller
     no strict 'refs';
-    *{ $target.PKG.DEBUG } = \$DEBUG;
+    *{ $target.PKG.DEBUG } = \$DEBUGGING;
 
-    # set $DEBUG_MODULE in this class to contain the argument passed - a list
+    # set $DEBUG in this class to contain the argument passed - a list
     # of class names to enable $DEBUG in when/if debugging is enabled
-    my $modules = shift @$symbols;
-    return unless $modules;           # zero/false for no debugging
-    $class->debug_modules($modules);
+    my $value = shift @$symbols;
+    return unless $value;           # zero/false for no debugging
+    $class->debug($value);
+}
+
+sub _skip_hook {
+    my ($class, $target, $key, $symbols, $import) = @_;
+    $MANAGER->skip_all(shift @$symbols);
 }
 
 sub manager {
@@ -96,18 +86,11 @@ sub args {
         elsif ($arg =~ /^(-s|--summary)$/) {
             $self->summary(1);
         }
-        elsif ($arg =~ /^(-t|--trace)$/) {
-            $self->trace(1);
-        }
-        elsif ($arg =~ /^(-h|--help)$/) {
-            warn $self->help;
-            exit;
-        }
         else {
             unshift(@$args, $arg);
             last;
         }
-    }  
+     }  
 }
 
 sub tests {
@@ -115,36 +98,22 @@ sub tests {
     plan(@_);
 }
 
-sub debug_modules {
+sub debug {
     my $self = shift;
-    $self->class->var( DEBUG_MODULES => shift );
+    $self->class->var( DEBUG => shift );
 }
 
 sub debugging {
-    my $self    = shift;
-    my $flag    = $DEBUG = shift || 1;
-    my $modules = $self->class->var(DEBUG_MODULES) || return;
-    $DEBUGGER->debug_modules($modules);
+    my $self  = shift;
+    my $flag  = $DEBUGGING = shift || 1;
+    my $debug = $self->class->var('DEBUG') || return;
+    $debug = [ split(DELIMITER, $debug) ] unless ref $debug eq ARRAY;
+    
+    foreach my $pkg (@$debug) {
+        class($pkg)->load->var( DEBUG => $flag );
+    }
 }
 
-sub trace {
-    my $self = shift;
-    my $flag = shift || 1;
-    $EXCEPTION->trace($flag);
-}
-
-sub help {
-    return <<END_OF_HELP;
-Options:
-    -d      --debug             Enable debugging
-    -t      --trace             Enable stack tracing
-    -c      --colour/--color    Enable colour output
-    -s      --summary           Display summary of test results
-    -h      --help              This help summary
-END_OF_HELP
-}
-
-
 class->methods(
     plan      => sub ($;$)  { manager->plan(@_)      },
     ok        => sub ($;$)  { manager->ok(@_)        },
@@ -255,13 +224,7 @@ Pass a test.
 
 Fail a test.
 
-    fail('Stonehenge in danger of being crushed by a dwarf');
-
-=head2 skip($reason)
-
-Skip a single test.
-
-    skip("That's just nit-picking isn't it?");
+    fail('Stonehenge crushed by a dwarf');
 
 =head2 skip_all($reason)
 
@@ -302,33 +265,6 @@ L<Badger::Test::Manager>.
     # defining a custom manager class
     Badger::Test->manager('My::Test::Manager');
 
-=head2 args(@args)
-
-This method can be used to set various testing options from command line 
-arguments.  It is typically called via the L<args> import option.
-
-    use Badger::Test
-        debug => 'My::Module',
-        args  => \@ARGV,
-        tests => 42;
-
-The method parses the arguments looking for the following options:
-
-    -d      --debug             Enable debugging
-    -t      --trace             Enable stack tracing
-    -c      --colour/--color    Enable colour output
-    -s      --summary           Display summary of test results
-    -h      --help              This help summary
-    
-Arguments can be passed as a list or reference to a list.  
-
-    Badger::Test->args(@ARGV);      # either
-    Badger::Test->args(\@ARGV);     # or
-
-Any of the arguments listed above appearing at the start of the list will be
-removed from the list and acted upon. Processing will end as soon as an
-unrecognised argument is encountered.
-
 =head2 summary()
 
 Prints a summary of the test results.  Delegates to L<Badger::Test::Manager>
@@ -345,7 +281,18 @@ Method to enable or disable colour output.
 
 An alias for L<colour()>.
 
-=head2 debug_modules($modules)
+=head2 args(@args)
+
+This method parses the arguments looking for C<-d> to enable debugging, C<-c>
+to enable colour output or C<-s> to print a test summary. This method is
+called by the L<args> import hook. Arguments can also be passed as a reference
+to a list, in which case any C<-c>, C<-d> or C<-s> arguments at the start will
+be removed.
+
+    Badger::Test->args(@ARGV);      # either
+    Badger::Test->args(\@ARGV);     # or
+
+=head2 debug($modules)
 
 This method can be called to define one or more modules that should have their
 C<$DEBUG> flag enabled when running in debug mode (i.e. with the C<-d> command
@@ -361,27 +308,14 @@ Multiple modules can be specified in a single string or by reference to a list.
     # list reference
     Badger::Test->debug(['My::Badger::Module', 'Your::Badger::Module']);  
 
-This method simply stores the list of modules in the C<$DEBUG_MODULES> 
-package variable for the L<debugging()> method to use.
-
 =head2 debugging($flag)
 
 This method enables or disables debugging for all modules named in the 
-C<$DEBUG_MODULES> list.  It also sets the internal C<$DEBUG> flag.
+C<$DEBUG> list.  It also sets the C<$DEBUGGING> flag.
 
     Badger::Test->debugging(1);         # enable debugging
     Badger::Test->debugging(0);         # disable debugging
 
-=head2 trace($flag)
-
-This method enables or disables stack tracing in the L<Badger::Exception>
-module.
-
-=head2 help()
-
-This method returns the help text display when help is requested with the 
-C<-h> or C<--help> command line options.  See L<args()> for further details.
-
 =head1 IMPORT HOOKS
 
 The following import hooks are provided to allow you to load and configure the
@@ -456,7 +390,7 @@ Andy Wardley L<http://wardley.org/>
 
 =head1 COPYRIGHT
 
-Copyright (C) 1996-2009 Andy Wardley.  All Rights Reserved.
+Copyright (C) 1996-2008 Andy Wardley.  All Rights Reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
